@@ -3,7 +3,6 @@ Views for Centrifugo module.
 """
 
 from .admin_api import CentrifugoAdminAPIViewSet
-from .dashboard import dashboard_view
 from .monitoring import CentrifugoMonitorViewSet
 from .testing_api import CentrifugoTestingAPIViewSet
 
@@ -11,5 +10,4 @@ __all__ = [
     'CentrifugoMonitorViewSet',
     'CentrifugoAdminAPIViewSet',
     'CentrifugoTestingAPIViewSet',
-    'dashboard_view',
 ]
