@@ -7,16 +7,14 @@ Enhanced newsletter management with Material Icons and optimized queries.
 from django import forms
 from django.contrib import admin, messages
 from django.db.models import Count, Q
-from unfold.admin import ModelAdmin, TabularInline
+from unfold.admin import TabularInline
 from unfold.contrib.filters.admin import AutocompleteSelectFilter
 from unfold.contrib.forms.widgets import WysiwygWidget
 
-from django_cfg import ExportForm, ImportForm
 from django_cfg.modules.django_admin import (
+    ActionConfig,
     AdminConfig,
     BadgeField,
-    BooleanField,
-    CurrencyField,
     DateTimeField,
     FieldsetConfig,
     Icons,
@@ -27,6 +25,16 @@ from django_cfg.modules.django_admin import (
 from django_cfg.modules.django_admin.base import PydanticAdmin
 
 from ..models import EmailLog, Newsletter, NewsletterCampaign, NewsletterSubscription
+from .actions import (
+    activate_newsletters,
+    activate_subscriptions,
+    cancel_campaigns,
+    deactivate_newsletters,
+    deactivate_subscriptions,
+    enable_auto_subscribe,
+    schedule_campaigns,
+    send_campaigns,
+)
 from .filters import (
     EmailClickedFilter,
     EmailOpenedFilter,
@@ -109,7 +117,17 @@ emaillog_config = AdminConfig(
         "user__email",
         "newsletter__subject"
     ],
-    list_filter=["status", "created_at", "sent_at", "newsletter"],
+    list_filter=[
+        "status",
+        "created_at",
+        "sent_at",
+        "newsletter",
+        EmailOpenedFilter,
+        EmailClickedFilter,
+        HasUserFilter,
+        UserEmailFilter,
+        UserNameFilter
+    ],
 
     # Ordering
     ordering=["-created_at"],
@@ -121,24 +139,9 @@ class EmailLogAdmin(PydanticAdmin):
     """Admin interface for EmailLog using Django Admin Utilities v2.0."""
     config = emaillog_config
 
-    # Override list_display_links
-    list_display_links = ['subject_display']
-
-    # Override list_filter to add custom filters
-    list_filter = [
-        'status', 'created_at', 'sent_at', 'newsletter',
-        EmailOpenedFilter, EmailClickedFilter, HasUserFilter, UserEmailFilter, UserNameFilter
-    ]
-
-    # Autocomplete
-    autocomplete_fields = ['user']
-
     # Readonly fields
     readonly_fields = ['created_at', 'sent_at', 'newsletter']
 
-    # Raw ID fields
-    raw_id_fields = ['user', 'newsletter']
-
     # Fieldsets
     fieldsets = [
         FieldsetConfig(
@@ -310,6 +313,31 @@ newsletter_config = AdminConfig(
     search_fields=["title", "description"],
     list_filter=["is_active", "auto_subscribe", "created_at"],
 
+    # Actions
+    actions=[
+        ActionConfig(
+            name="activate_newsletters",
+            description="Activate newsletters",
+            variant="success",
+            icon=Icons.CHECK_CIRCLE,
+            handler=activate_newsletters
+        ),
+        ActionConfig(
+            name="deactivate_newsletters",
+            description="Deactivate newsletters",
+            variant="warning",
+            icon=Icons.CANCEL,
+            handler=deactivate_newsletters
+        ),
+        ActionConfig(
+            name="enable_auto_subscribe",
+            description="Enable auto subscribe",
+            variant="primary",
+            icon=Icons.AUTO_AWESOME,
+            handler=enable_auto_subscribe
+        ),
+    ],
+
     # Ordering
     ordering=["-created_at"],
 )
@@ -320,9 +348,6 @@ class NewsletterAdmin(PydanticAdmin):
     """Admin interface for Newsletter using Django Admin Utilities v2.0."""
     config = newsletter_config
 
-    # Override list_display_links
-    list_display_links = ['title_display']
-
     # Required for autocomplete (used by NewsletterSubscriptionAdmin and NewsletterCampaignAdmin)
     search_fields = ['title', 'description']
 
@@ -351,9 +376,6 @@ class NewsletterAdmin(PydanticAdmin):
         )
     ]
 
-    # Actions
-    actions = ['activate_newsletters', 'deactivate_newsletters', 'enable_auto_subscribe']
-
     # Custom display methods using @computed_field decorator
     @computed_field("Title")
     def title_display(self, obj: Newsletter) -> str:
@@ -405,25 +427,6 @@ class NewsletterAdmin(PydanticAdmin):
         # DateTimeField in display_fields handles formatting automatically
         return obj.created_at
 
-    # Old-style actions (no @action decorator)
-    def activate_newsletters(self, request, queryset):
-        """Activate selected newsletters."""
-        count = queryset.update(is_active=True)
-        messages.success(request, f"Successfully activated {count} newsletters.")
-    activate_newsletters.short_description = "Activate newsletters"
-
-    def deactivate_newsletters(self, request, queryset):
-        """Deactivate selected newsletters."""
-        count = queryset.update(is_active=False)
-        messages.warning(request, f"Successfully deactivated {count} newsletters.")
-    deactivate_newsletters.short_description = "Deactivate newsletters"
-
-    def enable_auto_subscribe(self, request, queryset):
-        """Enable auto subscribe for selected newsletters."""
-        count = queryset.update(auto_subscribe=True)
-        messages.info(request, f"Enabled auto subscribe for {count} newsletters.")
-    enable_auto_subscribe.short_description = "Enable auto subscribe"
-
 
 # ===== NewsletterSubscription Inline (unchanged) =====
 
@@ -494,6 +497,24 @@ newslettersubscription_config = AdminConfig(
     search_fields=["email", "user__email", "newsletter__title"],
     list_filter=["is_active", "newsletter", "subscribed_at"],
 
+    # Actions
+    actions=[
+        ActionConfig(
+            name="activate_subscriptions",
+            description="Activate subscriptions",
+            variant="success",
+            icon=Icons.CHECK_CIRCLE,
+            handler=activate_subscriptions
+        ),
+        ActionConfig(
+            name="deactivate_subscriptions",
+            description="Deactivate subscriptions",
+            variant="warning",
+            icon=Icons.CANCEL,
+            handler=deactivate_subscriptions
+        ),
+    ],
+
     # Ordering
     ordering=["-subscribed_at"],
 )
@@ -504,15 +525,9 @@ class NewsletterSubscriptionAdmin(PydanticAdmin):
     """Admin interface for NewsletterSubscription using Django Admin Utilities v2.0."""
     config = newslettersubscription_config
 
-    # Override list_display_links
-    list_display_links = ['email_display']
-
     # Readonly fields
     readonly_fields = ['subscribed_at', 'unsubscribed_at']
 
-    # Autocomplete
-    autocomplete_fields = ['user', 'newsletter']
-
     # Fieldsets
     fieldsets = [
         FieldsetConfig(
@@ -529,9 +544,6 @@ class NewsletterSubscriptionAdmin(PydanticAdmin):
         )
     ]
 
-    # Actions
-    actions = ['activate_subscriptions', 'deactivate_subscriptions']
-
     # Custom display methods using @computed_field decorator
     @computed_field("Email")
     def email_display(self, obj: NewsletterSubscription) -> str:
@@ -576,19 +588,6 @@ class NewsletterSubscriptionAdmin(PydanticAdmin):
         # DateTimeField in display_fields handles formatting automatically
         return obj.unsubscribed_at
 
-    # Old-style actions (no @action decorator)
-    def activate_subscriptions(self, request, queryset):
-        """Activate selected subscriptions."""
-        count = queryset.update(is_active=True)
-        messages.success(request, f"Successfully activated {count} subscriptions.")
-    activate_subscriptions.short_description = "Activate subscriptions"
-
-    def deactivate_subscriptions(self, request, queryset):
-        """Deactivate selected subscriptions."""
-        count = queryset.update(is_active=False)
-        messages.warning(request, f"Successfully deactivated {count} subscriptions.")
-    deactivate_subscriptions.short_description = "Deactivate subscriptions"
-
 
 # ===== NewsletterCampaign Form (unchanged) =====
 
@@ -649,6 +648,33 @@ newslettercampaign_config = AdminConfig(
     search_fields=["subject", "newsletter__title", "main_html_content"],
     list_filter=["status", "newsletter", "sent_at"],
 
+    # Actions
+    actions=[
+        ActionConfig(
+            name="send_campaigns",
+            description="Send campaigns",
+            variant="primary",
+            icon=Icons.SEND,
+            confirmation=True,
+            handler=send_campaigns
+        ),
+        ActionConfig(
+            name="schedule_campaigns",
+            description="Schedule campaigns",
+            variant="warning",
+            icon=Icons.SCHEDULE,
+            handler=schedule_campaigns
+        ),
+        ActionConfig(
+            name="cancel_campaigns",
+            description="Cancel campaigns",
+            variant="danger",
+            icon=Icons.CANCEL,
+            confirmation=True,
+            handler=cancel_campaigns
+        ),
+    ],
+
     # Ordering
     ordering=["-created_at"],
 )
@@ -662,15 +688,9 @@ class NewsletterCampaignAdmin(PydanticAdmin):
     # Custom form
     form = NewsletterCampaignAdminForm
 
-    # Override list_display_links
-    list_display_links = ['subject_display']
-
     # Readonly fields
     readonly_fields = ['sent_at', 'recipient_count', 'created_at']
 
-    # Autocomplete
-    autocomplete_fields = ['newsletter']
-
     # Fieldsets
     fieldsets = [
         FieldsetConfig(
@@ -692,9 +712,6 @@ class NewsletterCampaignAdmin(PydanticAdmin):
         )
     ]
 
-    # Actions
-    actions = ['send_campaigns', 'schedule_campaigns', 'cancel_campaigns']
-
     # Custom display methods using @computed_field decorator
     @computed_field("Subject")
     def subject_display(self, obj: NewsletterCampaign) -> str:
@@ -756,40 +773,6 @@ class NewsletterCampaignAdmin(PydanticAdmin):
         else:
             return f"{count} recipients"
 
-    # Old-style actions (no @action decorator)
-    def send_campaigns(self, request, queryset):
-        """Send selected campaigns."""
-        sendable_count = queryset.filter(status__in=['draft', 'scheduled']).count()
-        if sendable_count == 0:
-            messages.error(request, "No sendable campaigns selected.")
-            return
-
-        queryset.filter(status__in=['draft', 'scheduled']).update(status='sending')
-        messages.success(request, f"Started sending {sendable_count} campaigns.")
-    send_campaigns.short_description = "Send campaigns"
-
-    def schedule_campaigns(self, request, queryset):
-        """Schedule selected campaigns."""
-        schedulable_count = queryset.filter(status='draft').count()
-        if schedulable_count == 0:
-            messages.error(request, "No draft campaigns selected.")
-            return
-
-        queryset.filter(status='draft').update(status='scheduled')
-        messages.warning(request, f"Scheduled {schedulable_count} campaigns.")
-    schedule_campaigns.short_description = "Schedule campaigns"
-
-    def cancel_campaigns(self, request, queryset):
-        """Cancel selected campaigns."""
-        cancelable_count = queryset.filter(status__in=['draft', 'scheduled']).count()
-        if cancelable_count == 0:
-            messages.error(request, "No cancelable campaigns selected.")
-            return
-
-        queryset.filter(status__in=['draft', 'scheduled']).update(status='cancelled')
-        messages.error(request, f"Cancelled {cancelable_count} campaigns.")
-    cancel_campaigns.short_description = "Cancel campaigns"
-
     def changelist_view(self, request, extra_context=None):
         """Add campaign statistics to changelist."""
         extra_context = extra_context or {}
