@@ -32,6 +32,7 @@ from ...models import (
 from ...models.ngrok import NgrokConfig
 from ...models.payments import PaymentsConfig
 from ...models.tasks import TaskConfig
+from ...modules.nextjs_admin import NextJsAdminConfig
 from ..exceptions import ConfigurationError
 from ..types.enums import EnvironmentMode, StartupInfoMode
 
@@ -149,6 +150,11 @@ class DjangoConfig(BaseModel):
         description="Enable django-cfg Maintenance application (multi-site maintenance mode with Cloudflare)",
     )
 
+    enable_frontend: bool = Field(
+        default=True,
+        description="Enable django-cfg Frontend application (Next.js admin panel static serving)",
+    )
+
     # === Payment System Configuration ===
     payments: Optional[PaymentsConfig] = Field(
         default=None,
@@ -347,6 +353,15 @@ class DjangoConfig(BaseModel):
         description="Custom middleware classes (standard middleware added automatically)",
     )
 
+    # === Next.js Admin Integration ===
+    nextjs_admin: Optional["NextJsAdminConfig"] = Field(
+        default=None,
+        description=(
+            "Next.js admin panel integration. "
+            "Example: NextJsAdminConfig(project_path='../django_admin')"
+        ),
+    )
+
     # === Internal State (Private) ===
     _base_dir: Optional[Path] = PrivateAttr(default=None)
     _django_settings: Optional[Dict[str, Any]] = PrivateAttr(default=None)
