@@ -5,6 +5,7 @@ Provides automatic URL registration for django_cfg endpoints and integrations.
 """
 
 import importlib
+import sys
 from typing import List, Set
 
 from django.conf import settings
@@ -20,8 +21,8 @@ def _get_openapi_group_urls() -> List[URLPattern]:
     For each OpenAPI group defined in config:
     1. Get the group from OpenAPI service
     2. Get the apps for that group
-    3. If the group has exactly 1 app with urls.py, include it
-    4. Add path("{api_prefix}/{group_name}/", include("{app}.urls"))
+    3. For each app with urls.py, include it
+    4. Add path("{api_prefix}/{app_basename}/", include("{app}.urls"))
 
     Returns:
         List of URL patterns for OpenAPI groups
@@ -41,17 +42,13 @@ def _get_openapi_group_urls() -> List[URLPattern]:
         api_prefix = getattr(service.config, 'api_prefix', 'api') or 'api'
         api_prefix = api_prefix.rstrip('/')  # Remove trailing slash
 
-        # Track already added groups to avoid duplicates
-        added_groups: Set[str] = set()
+        # Track already added apps to avoid duplicates
+        added_apps: Set[str] = set()
 
         # Get all groups from config
         for group_config in service.config.groups:
             group_name = group_config.name
 
-            # Skip if already added
-            if group_name in added_groups:
-                continue
-
             # Skip the internal "cfg" group - it's handled separately
             if group_name == "cfg":
                 continue
@@ -59,34 +56,36 @@ def _get_openapi_group_urls() -> List[URLPattern]:
             # Get apps for this group
             apps = group_config.apps
 
-            # Only auto-include if the group has exactly 1 app
-            if len(apps) != 1:
-                continue
+            # Process each app in the group
+            for app_name in apps:
+                # Skip if already added
+                if app_name in added_apps:
+                    continue
 
-            app_name = apps[0]
+                # Check if the app has a urls.py module
+                try:
+                    urls_module = f"{app_name}.urls"
+                    importlib.import_module(urls_module)
 
-            # Check if the app has a urls.py module
-            try:
-                urls_module = f"{app_name}.urls"
-                importlib.import_module(urls_module)
+                    # Get the app basename (last part of the app path)
+                    # e.g., "apps.workspaces" -> "workspaces"
+                    app_basename = app_name.split('.')[-1]
 
-                # Add URL pattern for this group
-                url_pattern = f"{api_prefix}/{group_name}/"
-                patterns.append(path(url_pattern, include(urls_module)))
-                added_groups.add(group_name)
+                    # Add URL pattern for this app
+                    url_pattern = f"{api_prefix}/{app_basename}/"
+                    patterns.append(path(url_pattern, include(urls_module)))
+                    added_apps.add(app_name)
 
-                # Log successful auto-registration
-                import sys
-                sys.stderr.write(f"✅ Auto-registered URL: /{url_pattern} -> {urls_module}\n")
-                sys.stderr.flush()
+                    # Log successful auto-registration
+                    sys.stderr.write(f"✅ Auto-registered URL: /{url_pattern} -> {urls_module}\n")
+                    sys.stderr.flush()
 
-            except ImportError:
-                # App doesn't have urls.py - skip it
-                continue
+                except ImportError:
+                    # App doesn't have urls.py - skip it
+                    continue
 
     except Exception as e:
         # Don't break if OpenAPI config is not available
-        import sys
         sys.stderr.write(f"❌ ERROR: Could not auto-add OpenAPI group URLs: {e}\n")
         sys.stderr.flush()
 
