@@ -4,6 +4,7 @@ Django-specific configuration models for django_cfg.
 Django integrations and extensions.
 """
 
+from .axes import AxesConfig
 from .constance import ConstanceConfig, ConstanceField
 from .environment import EnvironmentConfig
 from .openapi import OpenAPIClientConfig
@@ -13,4 +14,5 @@ __all__ = [
     "ConstanceConfig",
     "ConstanceField",
     "OpenAPIClientConfig",
+    "AxesConfig",
 ]
