@@ -138,16 +138,27 @@ class CounterBadge:
     """Counter badge utilities."""
 
     @classmethod
-    def simple(cls, count: int, label: str = None) -> SafeString:
-        """Simple counter badge."""
-        if count == 0:
-            variant = BadgeVariant.SECONDARY
-        elif count < 10:
-            variant = BadgeVariant.INFO
-        elif count < 100:
-            variant = BadgeVariant.WARNING
-        else:
-            variant = BadgeVariant.SUCCESS
+    def simple(cls, count: int, label: str = None, icon: Optional[str] = None,
+               variant: Optional[Union[BadgeVariant, str]] = None) -> SafeString:
+        """
+        Simple counter badge with optional icon.
+
+        Args:
+            count: The number to display
+            label: Optional label to append (e.g., "links", "items")
+            icon: Optional Material Icon name
+            variant: Optional variant to override auto color selection
+        """
+        # Auto-select variant based on count if not provided
+        if variant is None:
+            if count == 0:
+                variant = BadgeVariant.SECONDARY
+            elif count < 10:
+                variant = BadgeVariant.INFO
+            elif count < 100:
+                variant = BadgeVariant.WARNING
+            else:
+                variant = BadgeVariant.SUCCESS
 
         # Format with humanize for large numbers
         if count >= 1000:
@@ -157,4 +168,4 @@ class CounterBadge:
 
         display_text = f"{count_text} {label}" if label else count_text
 
-        return StatusBadge.create(display_text, variant)
+        return StatusBadge.create(display_text, variant, icon=icon)
