@@ -474,9 +474,12 @@ class BaseParser(ABC):
         if schema.items is not None:
             return "array"
 
-        # Special case: JSONField from Django has no type but description mentions JSON
-        if schema.description and 'JSON' in schema.description:
-            return "object"
+        # Special case: JSONField from Django has no type but description hints at dict/object
+        # Check for keywords like: JSON, configuration, settings, config, dict
+        if schema.description:
+            desc_lower = schema.description.lower()
+            if any(keyword in desc_lower for keyword in ['json', 'configuration', 'settings', 'config', 'dict']):
+                return "object"
 
         return "string"  # Default
 
