@@ -43,6 +43,12 @@ class Command(BaseCommand):
             help="Generate Go client only",
         )
 
+        parser.add_argument(
+            "--proto",
+            action="store_true",
+            help="Generate Protocol Buffer/gRPC definitions only",
+        )
+
         parser.add_argument(
             "--no-python",
             action="store_true",
@@ -61,6 +67,12 @@ class Command(BaseCommand):
             help="Skip Go client generation",
         )
 
+        parser.add_argument(
+            "--no-proto",
+            action="store_true",
+            help="Skip Protocol Buffer generation",
+        )
+
         # Utility options
         parser.add_argument(
             "--dry-run",
@@ -205,22 +217,31 @@ class Command(BaseCommand):
     def _generate_clients(self, service, options):
         """Generate clients."""
         # Determine languages
-        if options["python"] and not options["typescript"] and not options["go"]:
+        if options["python"] and not options["typescript"] and not options["go"] and not options["proto"]:
             python = True
             typescript = False
             go = False
-        elif options["typescript"] and not options["python"] and not options["go"]:
+            proto = False
+        elif options["typescript"] and not options["python"] and not options["go"] and not options["proto"]:
             python = False
             typescript = True
             go = False
-        elif options["go"] and not options["python"] and not options["typescript"]:
+            proto = False
+        elif options["go"] and not options["python"] and not options["typescript"] and not options["proto"]:
             python = False
             typescript = False
             go = True
+            proto = False
+        elif options["proto"] and not options["python"] and not options["typescript"] and not options["go"]:
+            python = False
+            typescript = False
+            go = False
+            proto = True
         else:
             python = not options["no_python"]
             typescript = not options["no_typescript"]
             go = not options["no_go"]
+            proto = not options["no_proto"]
 
         # Get groups
         groups = options.get("groups")
@@ -254,6 +275,8 @@ class Command(BaseCommand):
             self.stdout.write("  → TypeScript")
         if go:
             self.stdout.write("  → Go")
+        if proto:
+            self.stdout.write("  → Protocol Buffers (proto3)")
 
         if dry_run:
             self.stdout.write(self.style.WARNING("\n✅ Dry run completed - no files generated"))
@@ -271,6 +294,7 @@ class Command(BaseCommand):
             ArchiveManager,
             GoGenerator,
             GroupManager,
+            ProtoGenerator,
             PythonGenerator,
             TypeScriptGenerator,
             parse_openapi,
@@ -444,6 +468,26 @@ class Command(BaseCommand):
 
                     self.stdout.write(f"  ✅ Go client: {go_dir} ({len(go_files)} files)")
 
+                # Generate Proto files
+                if proto:
+                    self.stdout.write("  → Generating Protocol Buffer definitions...")
+                    proto_dir = clients_dir / "proto" / group_name
+                    proto_dir.mkdir(parents=True, exist_ok=True)
+
+                    proto_generator = ProtoGenerator(
+                        ir_context,
+                        split_files=True,  # Generate separate messages.proto and services.proto
+                        package_name=f"{group_name}.v1",
+                    )
+                    proto_files = proto_generator.generate()
+
+                    for generated_file in proto_files:
+                        full_path = proto_dir / generated_file.path
+                        full_path.parent.mkdir(parents=True, exist_ok=True)
+                        full_path.write_text(generated_file.content)
+
+                    self.stdout.write(f"  ✅ Proto files: {proto_dir} ({len(proto_files)} files)")
+
                 # Archive if enabled
                 if service.config.enable_archive:
                     self.stdout.write("  → Archiving...")
@@ -452,6 +496,8 @@ class Command(BaseCommand):
                         group_name,
                         python_dir=service.config.get_group_python_dir(group_name) if python else None,
                         typescript_dir=service.config.get_group_typescript_dir(group_name) if typescript else None,
+                        go_dir=go_dir if go else None,
+                        proto_dir=proto_dir if proto else None,
                     )
                     if archive_result.get('success'):
                         self.stdout.write(f"  ✅ Archived: {archive_result['archive_path']}")
@@ -464,6 +510,13 @@ class Command(BaseCommand):
                 import traceback
                 traceback.print_exc()
 
+        # Build and copy to Next.js admin (if configured)
+        if typescript and success_count > 0:
+            # First copy API clients
+            self._copy_to_nextjs_admin(service)
+            # Then build Next.js (so clients are included in build)
+            self._build_nextjs_admin()
+
         # Summary
         self.stdout.write("\n" + "=" * 60)
         if error_count == 0:
@@ -479,3 +532,216 @@ class Command(BaseCommand):
             self.stdout.write(f"  TypeScript: {service.config.get_typescript_clients_dir()}")
         if go:
             self.stdout.write(f"  Go:         {service.config.get_go_clients_dir()}")
+
+    def _copy_to_nextjs_admin(self, service):
+        """Copy TypeScript clients to Next.js admin project (if configured)."""
+        try:
+            from django_cfg.core.config import get_current_config
+            from pathlib import Path
+            import shutil
+
+            config = get_current_config()
+            if not config or not config.nextjs_admin:
+                return
+
+            nextjs_config = config.nextjs_admin
+            if not nextjs_config.auto_copy_api:
+                return
+
+            # Resolve Next.js project path
+            base_dir = config.base_dir
+            project_path = Path(nextjs_config.project_path)
+            if not project_path.is_absolute():
+                project_path = base_dir / project_path
+
+            if not project_path.exists():
+                self.stdout.write(self.style.WARNING(
+                    f"\n⚠️  Next.js project not found: {project_path}"
+                ))
+                return
+
+            # Resolve API output path
+            api_output_path = project_path / nextjs_config.get_api_output_path()
+
+            # Source: TypeScript clients directory
+            ts_source = service.config.get_typescript_clients_dir()
+
+            if not ts_source.exists():
+                return
+
+            self.stdout.write(f"\n📦 Copying TypeScript clients to Next.js admin...")
+
+            # Copy each group (exclude 'cfg' for Next.js admin)
+            copied_count = 0
+            for group_dir in ts_source.iterdir():
+                if not group_dir.is_dir():
+                    continue
+
+                group_name = group_dir.name
+
+                # Skip 'cfg' group for Next.js admin
+                if group_name == 'cfg':
+                    self.stdout.write(f"  ⏭️  Skipping 'cfg' group (excluded from Next.js admin)")
+                    continue
+
+                target_dir = api_output_path / group_name
+
+                # Remove old
+                if target_dir.exists():
+                    shutil.rmtree(target_dir)
+
+                # Copy new
+                shutil.copytree(group_dir, target_dir)
+                copied_count += 1
+
+                self.stdout.write(f"  ✅ {group_name} → {target_dir.relative_to(project_path)}")
+
+            if copied_count > 0:
+                self.stdout.write(self.style.SUCCESS(
+                    f"\n✅ Copied {copied_count} group(s) to Next.js admin!"
+                ))
+
+        except Exception as e:
+            self.stdout.write(self.style.ERROR(f"\n❌ Failed to copy to Next.js admin: {e}"))
+            import traceback
+            traceback.print_exc()
+
+    def _build_nextjs_admin(self):
+        """Build Next.js admin static export (if configured)."""
+        try:
+            from django_cfg.core.config import get_current_config
+            from pathlib import Path
+            import subprocess
+            import shutil
+
+            config = get_current_config()
+            if not config or not config.nextjs_admin:
+                return
+
+            nextjs_config = config.nextjs_admin
+            if not nextjs_config.auto_build:
+                return
+
+            # Resolve Next.js project path
+            base_dir = config.base_dir
+            project_path = Path(nextjs_config.project_path)
+            if not project_path.is_absolute():
+                project_path = base_dir / project_path
+
+            if not project_path.exists():
+                self.stdout.write(self.style.WARNING(
+                    f"\n⚠️  Next.js project not found: {project_path}"
+                ))
+                return
+
+            self.stdout.write(f"\n🏗️  Building Next.js admin static export...")
+
+            # Check if pnpm is available
+            pnpm_path = shutil.which('pnpm')
+            if not pnpm_path:
+                self.stdout.write(self.style.WARNING(
+                    "\n⚠️  pnpm not found. Skipping Next.js build."
+                ))
+                self.stdout.write("   Install pnpm or set auto_build=False in NextJsAdminConfig")
+                return
+
+            # Run pnpm build with NEXT_PUBLIC_STATIC_BUILD=true for static export
+            try:
+                import os
+                env = os.environ.copy()
+                env['NEXT_PUBLIC_STATIC_BUILD'] = 'true'
+
+                result = subprocess.run(
+                    [pnpm_path, 'build'],
+                    cwd=str(project_path),
+                    capture_output=True,
+                    text=True,
+                    timeout=300,  # 5 minutes timeout
+                    env=env,
+                )
+
+                if result.returncode == 0:
+                    self.stdout.write(self.style.SUCCESS(
+                        f"\n✅ Next.js admin built successfully!"
+                    ))
+
+                    # Check build output
+                    static_output = project_path / nextjs_config.get_static_output_path()
+                    if static_output.exists():
+                        self.stdout.write(self.style.SUCCESS(
+                            f"   📁 Build output: {static_output.relative_to(base_dir)}"
+                        ))
+
+                        # Create ZIP archive for Django static (Docker-ready)
+                        django_static_zip = base_dir / "static" / "nextjs_admin.zip"
+
+                        try:
+                            # Ensure static directory exists
+                            django_static_zip.parent.mkdir(parents=True, exist_ok=True)
+
+                            # Remove old ZIP if exists
+                            if django_static_zip.exists():
+                                django_static_zip.unlink()
+
+                            # Check if zip command is available
+                            zip_path = shutil.which('zip')
+                            if not zip_path:
+                                self.stdout.write(self.style.WARNING(
+                                    "   ⚠️  zip command not found. Falling back to Python zipfile..."
+                                ))
+                                # Fallback to Python zipfile
+                                import zipfile
+                                with zipfile.ZipFile(django_static_zip, 'w', zipfile.ZIP_DEFLATED) as zipf:
+                                    for file_path in static_output.rglob('*'):
+                                        if file_path.is_file():
+                                            arcname = file_path.relative_to(static_output)
+                                            zipf.write(file_path, arcname)
+                            else:
+                                # Use system zip command (faster)
+                                subprocess.run(
+                                    [zip_path, '-r', '-q', str(django_static_zip), '.'],
+                                    cwd=str(static_output),
+                                    check=True
+                                )
+
+                            # Get ZIP size
+                            zip_size_mb = django_static_zip.stat().st_size / (1024 * 1024)
+
+                            self.stdout.write(self.style.SUCCESS(
+                                f"   ✅ Created ZIP archive: {django_static_zip.relative_to(base_dir)} ({zip_size_mb:.1f}MB)"
+                            ))
+                            self.stdout.write(self.style.SUCCESS(
+                                f"   📍 ZIP location: {django_static_zip.relative_to(base_dir)}"
+                            ))
+                            self.stdout.write(self.style.SUCCESS(
+                                "   ℹ️  This ZIP is used by NextJsAdminView (Tab 2: External Admin)"
+                            ))
+
+                        except Exception as zip_error:
+                            self.stdout.write(self.style.ERROR(
+                                f"   ❌ Failed to create ZIP archive: {zip_error}"
+                            ))
+                    else:
+                        self.stdout.write(self.style.WARNING(
+                            f"   ⚠️  Build output not found at: {static_output.relative_to(base_dir)}"
+                        ))
+                else:
+                    self.stdout.write(self.style.ERROR(
+                        f"\n❌ Next.js build failed with exit code {result.returncode}"
+                    ))
+                    if result.stderr:
+                        self.stdout.write(self.style.ERROR(f"   Error: {result.stderr[:500]}"))
+
+            except subprocess.TimeoutExpired:
+                self.stdout.write(self.style.ERROR(
+                    "\n❌ Next.js build timed out (5 minutes)"
+                ))
+            except Exception as build_error:
+                self.stdout.write(self.style.ERROR(
+                    f"\n❌ Build command failed: {build_error}"
+                ))
+
+        except Exception as e:
+            self.stdout.write(self.style.ERROR(f"\n❌ Failed to build Next.js admin: {e}"))
+            import traceback
+            traceback.print_exc()
